pub enum SystemHeading {
PlacementChanged,
CompositionChanged,
}Expand description
The heading a system change is listed under (rsdl reference 14).
Variants
PlacementChanged
A change in a deployment.
CompositionChanged
A change to the closure or to a component’s lines.