diff_systems

Function diff_systems 

pub fn diff_systems(old: &System, new: &System) -> Vec<SystemChange>
Compares two lowered systems: the composition changes first, in the new closure’s order and then the removed components, and then the placement changes, deployment by deployment in the new system’s order and then the removed deployments.