pub fn diff_systems(old: &System, new: &System) -> Vec<SystemChange>Expand description
Compares two lowered systems: the composition changes first, in the new closure’s order and then the removed components, and then the placement changes, deployment by deployment in the new system’s order and then the removed deployments.